@@ -1,2 +1,6 @@
+"""
+test
+"""
+
 from .config import GENOME_VERSION
 from .main import rnpfind
